@@ -91,15 +91,18 @@ class VotesField(object):
                 verbose_name_plural = _('Votes')
 
             def save(self, *args, **kwargs):
-                super(Vote, self).save(*args, **kwargs)
-
-                if self.pk is not None:
+                changed = False
+                if self.pk:
                     orig_vote = Vote.objects.get(pk=self.pk)
                     if orig_vote.value != self.value:
-                        vote_changed.send(sender=self)
+                        changed = True
                 else:
-                    vote_changed.send(sender=self)
+                    changed = True
 
+                super(Vote, self).save(*args, **kwargs)
+
+                if vote_changed:
+                    vote_changed.send(sender=self)
             
             def delete(self, *args, **kwargs):
                 super(Vote, self).delete(*args, **kwargs)
